<?php
/**
 * Fashion Blogs functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Fashion Blogs
 */

include get_theme_file_path( 'vendor/wptrt/autoload/src/Fashion_Blogs_Loader.php' );

$Fashion_Blogs_Loader = new \WPTRT\Autoload\Fashion_Blogs_Loader();

$Fashion_Blogs_Loader->fashion_blogs_add( 'WPTRT\\Customize\\Section', get_theme_file_path( 'vendor/wptrt/customize-section-button/src' ) );

$Fashion_Blogs_Loader->fashion_blogs_register();

if ( ! function_exists( 'fashion_blogs_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function fashion_blogs_setup() {

		/*
		 * Enable support for Post Formats.
		 *
		 * See: https://codex.wordpress.org/Post_Formats
		*/
		add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

		add_theme_support( 'woocommerce' );
		add_theme_support( "responsive-embeds" );
		add_theme_support( "align-wide" );
		add_theme_support( "wp-block-styles" );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

        add_image_size('fashion-blogs-featured-header-image', 2000, 660, true);

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'primary' => esc_html__( 'Primary','fashion-blogs' ),
	        'footer'=> esc_html__( 'Footer Menu','fashion-blogs' ),
        ) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'fashion_blogs_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 50,
			'width'       => 50,
			'flex-width'  => true,
		) );

		add_editor_style( array( '/editor-style.css' ) );
		add_action('wp_ajax_fashion_blogs_dismissable_notice', 'fashion_blogs_dismissable_notice');
	}
endif;
add_action( 'after_setup_theme', 'fashion_blogs_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function fashion_blogs_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'fashion_blogs_content_width', 1170 );
}
add_action( 'after_setup_theme', 'fashion_blogs_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function fashion_blogs_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'fashion-blogs' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'fashion-blogs' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Woocommerce Shop Page Sidebar', 'fashion-blogs' ),
		'id'            => 'woocommerce-shop-page-sidebar',
		'description'   => '',
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Woocommerce Single Product Page Sidebar', 'fashion-blogs' ),
		'id'            => 'woocommerce-single-product-page-sidebar',
		'description'   => '',
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 1', 'fashion-blogs' ),
		'id'            => 'fashion-blogs-footer1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="footer-column-widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 2', 'fashion-blogs' ),
		'id'            => 'fashion-blogs-footer2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="footer-column-widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 3', 'fashion-blogs' ),
		'id'            => 'fashion-blogs-footer3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="footer-column-widget-title">',
		'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'fashion_blogs_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function fashion_blogs_scripts() {

	require_once get_theme_file_path( 'inc/wptt-webfont-loader.php' );

	wp_enqueue_style(
		'Quicksand',
		wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Quicksand:wght@300;400;500;600;700&display=swap' ),
		array(),
		'1.0'
	);


	wp_enqueue_style( 'fashion-blogs-block-editor-style', get_theme_file_uri('/assets/css/block-editor-style.css') );

	// load bootstrap css
    wp_enqueue_style( 'bootstrap-css', get_template_directory_uri() . '/assets/css/bootstrap.css');

    wp_enqueue_style( 'owl.carousel-css', get_template_directory_uri() . '/assets/css/owl.carousel.css');

	wp_enqueue_style( 'fashion-blogs-style', get_stylesheet_uri() );
	require get_parent_theme_file_path( '/custom-option.php' );
	wp_add_inline_style( 'fashion-blogs-style',$fashion_blogs_theme_css );

	wp_style_add_data('fashion-blogs-basic-style', 'rtl', 'replace');

	// fontawesome
	wp_enqueue_style( 'fontawesome-style', get_template_directory_uri().'/assets/css/fontawesome/css/all.css' );

    wp_enqueue_script('fashion-blogs-theme-js', get_template_directory_uri() . '/assets/js/theme-script.js', array('jquery'), '', true );

    wp_enqueue_script('owl.carousel-js', get_template_directory_uri() . '/assets/js/owl.carousel.js', array('jquery'), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'fashion_blogs_scripts' );

/**
 * Enqueue theme color style.
 */
function fashion_blogs_theme_color() {

    $theme_color_css = '';
    $fashion_blogs_theme_color = get_theme_mod('fashion_blogs_theme_color');
    $fashion_blogs_theme_color_2 = get_theme_mod('fashion_blogs_theme_color_2');
    $fashion_blogs_preloader_bg_color = get_theme_mod('fashion_blogs_preloader_bg_color');
    $fashion_blogs_preloader_dot_1_color = get_theme_mod('fashion_blogs_preloader_dot_1_color');
    $fashion_blogs_preloader_dot_2_color = get_theme_mod('fashion_blogs_preloader_dot_2_color');
    $fashion_blogs_logo_max_height = get_theme_mod('fashion_blogs_logo_max_height');

  	if(get_theme_mod('fashion_blogs_logo_max_height') == '') {
		$fashion_blogs_logo_max_height = '24';
	}

    if(get_theme_mod('fashion_blogs_preloader_bg_color') == '') {
			$fashion_blogs_preloader_bg_color = '#000';
	}
	if(get_theme_mod('fashion_blogs_preloader_dot_1_color') == '') {
		$fashion_blogs_preloader_dot_1_color = '#fff';
	}
	if(get_theme_mod('fashion_blogs_preloader_dot_2_color') == '') {
		$fashion_blogs_preloader_dot_2_color = '#fd4597';
	}

	$theme_color_css = '
		.custom-logo-link img{
			max-height: '.esc_attr($fashion_blogs_logo_max_height).'px;
	 	}
		#button,.top_header p a,.social-link i:hover,.topbtn a,.slider-box-btn a,.sidebar input[type="submit"],.sidebar button[type="submit"],span.onsale,.pro-button a,.woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button,.woocommerce #respond input#submit.alt,.woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt,.pro-button a:hover,.woocommerce #respond input#submit:hover,.woocommerce a.button:hover,.woocommerce button.button:hover,.woocommerce input.button:hover,.woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover,.woocommerce .woocommerce-ordering select,.woocommerce-account .woocommerce-MyAccount-navigation ul li,.post-navigation .nav-previous a:hover,.post-navigation .nav-next a:hover,.posts-navigation .nav-previous a:hover,.posts-navigation .nav-next a:hover,.navigation.pagination .nav-links a.current, .navigation.pagination .nav-links a:hover,.navigation.pagination .nav-links span.current,.navigation.pagination .nav-links span:hover,.comment-respond input#submit,#colophon,.sidebar h5,.sidebar .tagcloud a:hover,.toggle-nav i,.sidenav .closebtn,a.added_to_cart.wc-forward{
			background: '.esc_attr($fashion_blogs_theme_color).';
		}
		a,#latest_post h2 i,a.btn-text,p.price,.woocommerce ul.products li.product .price,.woocommerce div.product p.price, .woocommerce div.product span.price,.woocommerce-message::before,.woocommerce-info::before,.main-navigation .menu > li > a:hover,.widget a:hover, .widget a:focus,.sidebar ul li a:hover{
			color: '.esc_attr($fashion_blogs_theme_color).';
		}
		.postcat-name{
			color: '.esc_attr($fashion_blogs_theme_color).'!important;
		}
		.woocommerce-message,.woocommerce-info,.post-navigation .nav-previous a:hover,.post-navigation .nav-next a:hover,.posts-navigation .nav-previous a:hover,.posts-navigation .nav-next a:hover,.navigation.pagination .nav-links a.current, .navigation.pagination .nav-links a:hover,.navigation.pagination .nav-links span.current,.navigation.pagination .nav-links span:hover,.wp-block-quote, .wp-block-quote:not(.is-large):not(.is-style-large), .wp-block-pullquote,.main-navigation .sub-menu > li > a{
			border-color: '.esc_attr($fashion_blogs_theme_color).';
		}
		.main-navigation .sub-menu > li > a:hover{
			border-color: '.esc_attr($fashion_blogs_theme_color).'!important;
		}
		#button:hover,#button:active,.slider-box,.slider-box-btn a:hover,.topbtn a:hover,.woocommerce-account .woocommerce-MyAccount-navigation ul li:hover,.pro-button a:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover, .woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover,a.added_to_cart.wc-forward:hover{
			background: '.esc_attr($fashion_blogs_theme_color_2).';
		}
		h1,h2,h3,h4,h5,h6,.article-box a,a:hover,.woocommerce ul.products li.product .star-rating, .woocommerce .star-rating{
			color: '.esc_attr($fashion_blogs_theme_color_2).';
		}
		.loading{
			background-color: '.esc_attr($fashion_blogs_preloader_bg_color).';
		 }
		 @keyframes loading {
		  0%,
		  100% {
		  	transform: translatey(-2.5rem);
		    background-color: '.esc_attr($fashion_blogs_preloader_dot_1_color).';
		  }
		  50% {
		  	transform: translatey(2.5rem);
		    background-color: '.esc_attr($fashion_blogs_preloader_dot_2_color).';
		  }
		}
	';
    wp_add_inline_style( 'fashion-blogs-style',$theme_color_css );

}
add_action( 'wp_enqueue_scripts', 'fashion_blogs_theme_color' );

/**
 * Enqueue S Header.
 */
function fashion_blogs_sticky_header() {

	$fashion_blogs_sticky_header = get_theme_mod('fashion_blogs_sticky_header');

	$fashion_blogs_custom_style= "";

	if($fashion_blogs_sticky_header != true){

		$fashion_blogs_custom_style .='.stick_header{';

			$fashion_blogs_custom_style .='position: static;';

		$fashion_blogs_custom_style .='}';
	}

	wp_add_inline_style( 'fashion-blogs-style',$fashion_blogs_custom_style );

}
add_action( 'wp_enqueue_scripts', 'fashion_blogs_sticky_header' );


/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/*radio button sanitization*/
function fashion_blogs_sanitize_choices( $input, $setting ) {
    global $wp_customize;
    $control = $wp_customize->get_control( $setting->id );
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

//SELECT
function fashion_blogs_sanitize_select( $input, $setting ){
    $input = sanitize_key($input);
    $choices = $setting->manager->get_control( $setting->id )->choices;
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/*dropdown page sanitization*/
function fashion_blogs_sanitize_dropdown_pages( $page_id, $setting ) {
	$page_id = absint( $page_id );
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

/*checkbox sanitization*/
function fashion_blogs_sanitize_checkbox( $input ) {
	// Boolean check
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

function fashion_blogs_sanitize_number_absint( $number, $setting ) {
	// Ensure $number is an absolute integer (whole number, zero or greater).
	$number = absint( $number );

	// If the input is an absolute integer, return it; otherwise, return the default
	return ( $number ? $number : $setting->default );
}

function fashion_blogs_sanitize_number_range( $number, $setting ) {
	
	// Ensure input is an absolute integer.
	$number = absint( $number );
	
	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;
	
	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );
	
	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );
	
	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );
	
	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}

//Change number or products per row to 3

add_filter('loop_shop_columns', 'fashion_blogs_loop_columns', 999);
if (!function_exists('fashion_blogs_loop_columns')) {
	function fashion_blogs_loop_columns() {
		return 3;
	}
}

function fashion_blogs_remove_sections( $wp_customize ) {
	$wp_customize->remove_control('display_header_text');
	$wp_customize->remove_setting('display_header_text');
	$wp_customize->remove_control('header_textcolor');
	$wp_customize->remove_setting('header_textcolor');
}
add_action( 'customize_register', 'fashion_blogs_remove_sections');

/**
 * Get CSS
 */

function fashion_blogs_getpage_css($hook) {
	wp_enqueue_script( 'fashion-blogs-admin-script', get_template_directory_uri() . '/inc/admin/js/fashion-blogs-admin-notice-script.js', array( 'jquery' ) );
    wp_localize_script( 'fashion-blogs-admin-script', 'fashion_blogs_ajax_object',
        array( 'ajax_url' => admin_url( 'admin-ajax.php' ) )
    );
	if ( 'appearance_page_fashion-blogs-info' != $hook ) {
		return;
	}
	wp_enqueue_style( 'fashion-blogs-demo-style', get_template_directory_uri() . '/assets/css/demo.css' );
}
add_action( 'admin_enqueue_scripts', 'fashion_blogs_getpage_css' );

if ( ! defined( 'FASHION_BLOGS_CONTACT_SUPPORT' ) ) {
define('FASHION_BLOGS_CONTACT_SUPPORT',__('https://wordpress.org/support/theme/fashion-blogs/','fashion-blogs'));
}
if ( ! defined( 'FASHION_BLOGS_REVIEW' ) ) {
define('FASHION_BLOGS_REVIEW',__('https://wordpress.org/support/theme/fashion-blogs/reviews/','fashion-blogs'));
}
if ( ! defined( 'FASHION_BLOGS_LIVE_DEMO' ) ) {
define('FASHION_BLOGS_LIVE_DEMO',__('https://www.themagnifico.net/demo/fashion-blogs/','fashion-blogs'));
}
if ( ! defined( 'FASHION_BLOGS_GET_PREMIUM_PRO' ) ) {
define('FASHION_BLOGS_GET_PREMIUM_PRO',__('https://www.themagnifico.net/themes/fashion-blog-wordpress-theme/','fashion-blogs'));
}
if ( ! defined( 'FASHION_BLOGS_PRO_DOC' ) ) {
define('FASHION_BLOGS_PRO_DOC',__('https://www.themagnifico.net/eard/wathiqa/fashion-blogs-pro-doc/','fashion-blogs'));
}

add_action('admin_menu', 'fashion_blogs_themepage');
function fashion_blogs_themepage(){

	$fashion_blogs_theme_test = wp_get_theme();
	
	$theme_info = add_theme_page( __('Theme Options','fashion-blogs'), __('Theme Options','fashion-blogs'), 'manage_options', 'fashion-blogs-info.php', 'fashion_blogs_info_page' );
}

function fashion_blogs_info_page() {
	$user = wp_get_current_user();
	$theme = wp_get_theme();
	?>
	<div class="wrap about-wrap fashion-blogs-add-css">
		<div>
			<h1>
				<?php esc_html_e('Welcome To ','fashion-blogs'); ?><?php echo esc_html( $theme ); ?>
			</h1>
			<div class="feature-section three-col">
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Contact Support", "fashion-blogs"); ?></h3>
						<p><?php esc_html_e("Thank you for trying Fashion Blogs , feel free to contact us for any support regarding our theme.", "fashion-blogs"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( FASHION_BLOGS_CONTACT_SUPPORT ); ?>" class="button button-primary get">
							<?php esc_html_e("Contact Support", "fashion-blogs"); ?>
						</a></p>
					</div>
				</div>
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Checkout Premium", "fashion-blogs"); ?></h3>
						<p><?php esc_html_e("Our premium theme comes with extended features like demo content import , responsive layouts etc.", "fashion-blogs"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( FASHION_BLOGS_GET_PREMIUM_PRO ); ?>" class="button button-primary get">
							<?php esc_html_e("Get Premium", "fashion-blogs"); ?>
						</a></p>
					</div>
				</div>
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Review", "fashion-blogs"); ?></h3>
						<p><?php esc_html_e("If You love Fashion Blogs theme then we would appreciate your review about our theme.", "fashion-blogs"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( FASHION_BLOGS_REVIEW ); ?>" class="button button-primary get">
							<?php esc_html_e("Review", "fashion-blogs"); ?>
						</a></p>
					</div>
				</div>
			</div>
		</div>
		<hr>

		<h2><?php esc_html_e("Free Vs Premium","fashion-blogs"); ?></h2>
		<div class="fashion-blogs-button-container">
			<a target="_blank" href="<?php echo esc_url( FASHION_BLOGS_PRO_DOC ); ?>" class="button button-primary get">
				<?php esc_html_e("Checkout Documentation", "fashion-blogs"); ?>
			</a>
			<a target="_blank" href="<?php echo esc_url( FASHION_BLOGS_LIVE_DEMO ); ?>" class="button button-primary get">
				<?php esc_html_e("View Theme Demo", "fashion-blogs"); ?>
			</a>
		</div>

		<table class="wp-list-table widefat">
			<thead class="table-book">
				<tr>
					<th><strong><?php esc_html_e("Theme Feature", "fashion-blogs"); ?></strong></th>
					<th><strong><?php esc_html_e("Basic Version", "fashion-blogs"); ?></strong></th>
					<th><strong><?php esc_html_e("Premium Version", "fashion-blogs"); ?></strong></th>
				</tr>
			</thead>

			<tbody>
				<tr>
					<td><?php esc_html_e("Header Background Color", "fashion-blogs"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Custom Navigation Logo Or Text", "fashion-blogs"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Hide Logo Text", "fashion-blogs"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>

				<tr>
					<td><?php esc_html_e("Premium Support", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Fully SEO Optimized", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Recent Posts Widget", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>

				<tr>
					<td><?php esc_html_e("Easy Google Fonts", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Pagespeed Plugin", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Only Show Header Image On Front Page", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Show Header Everywhere", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Custom Text On Header Image", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Full Width (Hide Sidebar)", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Only Show Upper Widgets On Front Page", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Replace Copyright Text", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Upper Widgets Colors", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Navigation Color", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Post/Page Color", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Blog Feed Color", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Footer Color", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Sidebar Color", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Background Color", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Importable Demo Content	", "fashion-blogs"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
			</tbody>
		</table>
		<div class="fashion-blogs-button-container">
			<a target="_blank" href="<?php echo esc_url( FASHION_BLOGS_GET_PREMIUM_PRO ); ?>" class="button button-primary get">
				<?php esc_html_e("Go Premium", "fashion-blogs"); ?>
			</a>
		</div>
	</div>
	<?php
}

//Admin Notice For Getstart
function fashion_blogs_ajax_notice_handler() {
    if ( isset( $_POST['type'] ) ) {
        $type = sanitize_text_field( wp_unslash( $_POST['type'] ) );
        update_option( 'dismissed-' . $type, TRUE );
    }
}

function fashion_blogs_deprecated_hook_admin_notice() {

    $dismissed = get_user_meta(get_current_user_id(), 'fashion_blogs_dismissable_notice', true);
    if ( !$dismissed) { ?>
        <div class="updated notice notice-success is-dismissible notice-get-started-class" data-notice="get_started" style="background: #f7f9f9; padding: 20px 10px; display: flex;">
	    	<div class="tm-admin-image">
	    		<img style="width: 100%;max-width: 320px;line-height: 40px;display: inline-block;vertical-align: top;border: 2px solid #ddd;border-radius: 4px;" src="<?php echo esc_url(get_stylesheet_directory_uri()) .'/screenshot.png'; ?>" />
	    	</div>
	    	<div class="tm-admin-content" style="padding-left: 30px; align-self: center">
	    		<h2 style="font-weight: 600;line-height: 1.3; margin: 0px;"><?php esc_html_e('Thank You For Choosing ', 'fashion-blogs'); ?><?php echo wp_get_theme(); ?><h2>
	    		<p style="color: #3c434a; font-weight: 400; margin-bottom: 30px;"><?php _e('Get Started With Theme By Clicking On Getting Started.', 'fashion-blogs'); ?><p>
	        	<a class="admin-notice-btn button button-primary button-hero" href="<?php echo esc_url( admin_url( 'themes.php?page=fashion-blogs-info.php' )); ?>"><?php esc_html_e( 'Get started', 'fashion-blogs' ) ?></a>
	        	<a class="admin-notice-btn button button-primary button-hero" target="_blank" href="<?php echo esc_url( FASHION_BLOGS_PRO_DOC ); ?>"><?php esc_html_e( 'Documentation', 'fashion-blogs' ) ?></a>
	        	<span style="padding-top: 15px; display: inline-block; padding-left: 8px;">
	        	<span class="dashicons dashicons-admin-links"></span>
	        	<a class="admin-notice-btn"	 target="_blank" href="<?php echo esc_url( FASHION_BLOGS_LIVE_DEMO ); ?>"><?php esc_html_e( 'View Demo', 'fashion-blogs' ) ?></a>
	        	</span>
	    	</div>
        </div>
    <?php }
}

add_action( 'admin_notices', 'fashion_blogs_deprecated_hook_admin_notice' );

function fashion_blogs_switch_theme() {
    delete_user_meta(get_current_user_id(), 'fashion_blogs_dismissable_notice');
}
add_action('after_switch_theme', 'fashion_blogs_switch_theme');
function fashion_blogs_dismissable_notice() {
    update_user_meta(get_current_user_id(), 'fashion_blogs_dismissable_notice', true);
    die();
}