<?php
/**
 * Fashion Blogs Theme Customizer
 *
 * @link: https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @package Fashion Blogs
 */

if ( ! defined( 'FASHION_BLOGS_URL' ) ) {
define('FASHION_BLOGS_URL',__('https://www.themagnifico.net/themes/fashion-blog-wordpress-theme/','fashion-blogs'));
}
if ( ! defined( 'FASHION_BLOGS_BUY_TEXT' ) ) {
    define( 'FASHION_BLOGS_BUY_TEXT', __( 'Buy Fashion Blogs Pro','fashion-blogs' ));
}

use WPTRT\Customize\Section\Fashion_Blogs_Button;

add_action( 'customize_register', function( $manager ) {

    $manager->register_section_type( Fashion_Blogs_Button::class );

    $manager->add_section(
        new Fashion_Blogs_Button( $manager, 'fashion_blogs_pro', [
            'title'       => __( 'Fashion Blogs Pro', 'fashion-blogs' ),
            'priority'    => 0,
            'button_text' => __( 'GET PREMIUM', 'fashion-blogs' ),
            'button_url'  => esc_url( 'https://www.themagnifico.net/themes/fashion-blog-wordpress-theme/', 'fashion-blogs')
        ] )
    );

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

    $version = wp_get_theme()->get( 'Version' );

    wp_enqueue_script(
        'fashion-blogs-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
        [ 'customize-controls' ],
        $version,
        true
    );

    wp_enqueue_style(
        'fashion-blogs-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
        [ 'customize-controls' ],
        $version
    );

} );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function fashion_blogs_customize_register($wp_customize){

     // Pro Version
    class Fashion_Blogs_Customize_Pro_Version extends WP_Customize_Control {
        public $type = 'pro_options';

        public function render_content() {
            echo '<span>For More <strong>'. esc_html( $this->label ) .'</strong>?</span>';
            echo '<a href="'. esc_url($this->description) .'" target="_blank">';
                echo '<span class="dashicons dashicons-info"></span>';
                echo '<strong> '. esc_html( FASHION_BLOGS_BUY_TEXT,'fashion-blogs' ) .'<strong></a>';
            echo '</a>';
        }
    }

    // Custom Controls
    function Fashion_Blogs_sanitize_custom_control( $input ) {
        return $input;
    }

    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';

    //Logo
    $wp_customize->add_setting('fashion_blogs_logo_max_height',array(
        'default'   => '24',
        'sanitize_callback' => 'fashion_blogs_sanitize_number_absint'
    ));
    $wp_customize->add_control('fashion_blogs_logo_max_height',array(
        'label' => esc_html__('Logo Width','fashion-blogs'),
        'section'   => 'title_tagline',
        'type'      => 'number'
    ));

    $wp_customize->add_setting('fashion_blogs_logo_title', array(
        'default' => true,
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'fashion_blogs_logo_title',array(
        'label'          => __( 'Enable Disable Title', 'fashion-blogs' ),
        'section'        => 'title_tagline',
        'settings'       => 'fashion_blogs_logo_title',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('fashion_blogs_theme_description', array(
        'default' => false,
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'fashion_blogs_theme_description',array(
        'label'          => __( 'Enable Disable Tagline', 'fashion-blogs' ),
        'section'        => 'title_tagline',
        'settings'       => 'fashion_blogs_theme_description',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('fashion_blogs_logo_title_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'fashion_blogs_logo_title_color', array(
        'label'    => __('Site Title Color', 'fashion-blogs'),
        'section'  => 'title_tagline'
    )));

    $wp_customize->add_setting('fashion_blogs_logo_tagline_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'fashion_blogs_logo_tagline_color', array(
        'label'    => __('Site Tagline Color', 'fashion-blogs'),
        'section'  => 'title_tagline'
    )));

    // General Settings
     $wp_customize->add_section('fashion_blogs_general_settings',array(
        'title' => esc_html__('General Settings','fashion-blogs'),
        'priority'   => 30,
    ));

     $wp_customize->add_setting('fashion_blogs_sticky_header', array(
        'default' => false,
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'fashion_blogs_sticky_header',array(
        'label'          => __( 'Show Sticky Header', 'fashion-blogs' ),
        'section'        => 'fashion_blogs_general_settings',
        'settings'       => 'fashion_blogs_sticky_header',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('fashion_blogs_preloader_hide', array(
        'default' => '1',
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'fashion_blogs_preloader_hide',array(
        'label'          => __( 'Show Theme Preloader', 'fashion-blogs' ),
        'section'        => 'fashion_blogs_general_settings',
        'settings'       => 'fashion_blogs_preloader_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting( 'fashion_blogs_preloader_bg_color', array(
        'default' => '#000',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'fashion_blogs_preloader_bg_color', array(
        'label' => esc_html__('Preloader Background Color','fashion-blogs'),
        'section' => 'fashion_blogs_general_settings',
        'settings' => 'fashion_blogs_preloader_bg_color'
    )));

    $wp_customize->add_setting( 'fashion_blogs_preloader_dot_1_color', array(
        'default' => '#fff',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'fashion_blogs_preloader_dot_1_color', array(
        'label' => esc_html__('Preloader First Dot Color','fashion-blogs'),
        'section' => 'fashion_blogs_general_settings',
        'settings' => 'fashion_blogs_preloader_dot_1_color'
    )));

    $wp_customize->add_setting( 'fashion_blogs_preloader_dot_2_color', array(
        'default' => '#fd4597',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'fashion_blogs_preloader_dot_2_color', array(
        'label' => esc_html__('Preloader Second Dot Color','fashion-blogs'),
        'section' => 'fashion_blogs_general_settings',
        'settings' => 'fashion_blogs_preloader_dot_2_color'
    )));

    $wp_customize->add_setting('fashion_blogs_scroll_hide', array(
        'default' => false,
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'fashion_blogs_scroll_hide',array(
        'label'          => __( 'Show Theme Scroll To Top', 'fashion-blogs' ),
        'section'        => 'fashion_blogs_general_settings',
        'settings'       => 'fashion_blogs_scroll_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('fashion_blogs_scroll_top_position',array(
        'default' => 'Right',
        'sanitize_callback' => 'fashion_blogs_sanitize_choices'
    ));
    $wp_customize->add_control('fashion_blogs_scroll_top_position',array(
        'type' => 'radio',
        'section' => 'fashion_blogs_general_settings',
        'choices' => array(
            'Right' => __('Right','fashion-blogs'),
            'Left' => __('Left','fashion-blogs'),
            'Center' => __('Center','fashion-blogs')
        ),
    ) );

    //Woocommerce shop page Sidebar
    $wp_customize->add_setting('fashion_blogs_woocommerce_shop_page_sidebar', array(
        'default' => true,
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'fashion_blogs_woocommerce_shop_page_sidebar',array(
        'label'          => __( 'Hide Shop Page Sidebar', 'fashion-blogs' ),
        'section'        => 'fashion_blogs_general_settings',
        'settings'       => 'fashion_blogs_woocommerce_shop_page_sidebar',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('fashion_blogs_shop_page_sidebar_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'fashion_blogs_sanitize_choices'
    ));
    $wp_customize->add_control('fashion_blogs_shop_page_sidebar_layout',array(
        'type' => 'select',
        'label' => __('Woocommerce Shop Page Sidebar','fashion-blogs'),
        'section' => 'fashion_blogs_general_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','fashion-blogs'),
            'Right Sidebar' => __('Right Sidebar','fashion-blogs'),
        ),
    ) );

    //Woocommerce Single Product page Sidebar
    $wp_customize->add_setting('fashion_blogs_woocommerce_single_product_page_sidebar', array(
        'default' => true,
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'fashion_blogs_woocommerce_single_product_page_sidebar',array(
        'label'          => __( 'Hide Single Product Page Sidebar', 'fashion-blogs' ),
        'section'        => 'fashion_blogs_general_settings',
        'settings'       => 'fashion_blogs_woocommerce_single_product_page_sidebar',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('fashion_blogs_single_product_sidebar_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'fashion_blogs_sanitize_choices'
    ));
    $wp_customize->add_control('fashion_blogs_single_product_sidebar_layout',array(
        'type' => 'select',
        'label' => __('Woocommerce Single Product Page Sidebar','fashion-blogs'),
        'section' => 'fashion_blogs_general_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','fashion-blogs'),
            'Right Sidebar' => __('Right Sidebar','fashion-blogs'),
        ),
    ) );

    $wp_customize->add_setting('fashion_blogs_woocommerce_product_sale',array(
        'default' => 'Left',
        'sanitize_callback' => 'fashion_blogs_sanitize_choices'
    ));
    $wp_customize->add_control('fashion_blogs_woocommerce_product_sale',array(
        'type' => 'radio',
        'section' => 'fashion_blogs_general_settings',
        'choices' => array(
            'Right' => __('Right','fashion-blogs'),
            'Left' => __('Left','fashion-blogs'),
            'Center' => __('Center','fashion-blogs')
        ),
    ) );

    //Products border radius
    $wp_customize->add_setting( 'fashion_blogs_woo_product_border_radius', array(
        'default'              => '0',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'fashion_blogs_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'fashion_blogs_woo_product_border_radius', array(
        'label'       => esc_html__( 'Product Border Radius','fashion-blogs' ),
        'section'     => 'fashion_blogs_general_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 170,
        ),
    ) );

    // Pro Version
    $wp_customize->add_setting( 'pro_version_general_setting', array(
        'sanitize_callback' => 'Fashion_Blogs_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Fashion_Blogs_Customize_Pro_Version ( $wp_customize,'pro_version_general_setting', array(
        'section'     => 'fashion_blogs_general_settings',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'fashion-blogs' ),
        'description' => esc_url( FASHION_BLOGS_URL ),
        'priority'    => 100
    )));

    // Theme Color
    $wp_customize->add_section('fashion_blogs_color_option',array(
        'title' => esc_html__('Theme Color','fashion-blogs'),
        'priority'   => 20
    ));

    $wp_customize->add_setting( 'fashion_blogs_theme_color', array(
        'default' => '#fd4597',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'fashion_blogs_theme_color', array(
        'label' => esc_html__('First Color Option','fashion-blogs'),
        'section' => 'fashion_blogs_color_option',
        'settings' => 'fashion_blogs_theme_color'
    )));

    $wp_customize->add_setting( 'fashion_blogs_theme_color_2', array(
        'default' => '#101138',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'fashion_blogs_theme_color_2', array(
        'label' => esc_html__('Second Color Option','fashion-blogs'),
        'section' => 'fashion_blogs_color_option',
        'settings' => 'fashion_blogs_theme_color_2'
    )));

    
     // Pro Version
    $wp_customize->add_setting( 'pro_version_theme_color', array(
        'sanitize_callback' => 'Fashion_Blogs_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Fashion_Blogs_Customize_Pro_Version ( $wp_customize,'pro_version_theme_color', array(
        'section'     => 'fashion_blogs_color_option',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'fashion-blogs' ),
        'description' => esc_url( FASHION_BLOGS_URL ),
        'priority'    => 100
    )));

    // Top Header
    $wp_customize->add_section('fashion_blogs_top_header',array(
        'title' => esc_html__('Top Header','fashion-blogs'),
    ));

    $wp_customize->add_setting('fashion_blogs_top_header_setting', array(
        'default' => 0,
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'fashion_blogs_top_header_setting',array(
        'label'          => __( 'Enable Disable Top Header', 'fashion-blogs' ),
        'section'        => 'fashion_blogs_top_header',
        'settings'       => 'fashion_blogs_top_header_setting',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('fashion_blogs_topbar_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('fashion_blogs_topbar_text',array(
        'label' => esc_html__('Top Header Text','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_topbar_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('fashion_blogs_facebook_icon',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('fashion_blogs_facebook_icon',array(
        'label' => esc_html__('Add Facebook Icon','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_facebook_icon',
        'type'  => 'text',
        'default' => 'fab fa-facebook-f',
        'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fab fa-facebook-f','fashion-blogs')
    ));

    $wp_customize->add_setting('fashion_blogs_facebook_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('fashion_blogs_facebook_url',array(
        'label' => esc_html__('Facebook Link','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_facebook_url',
        'type'  => 'url'
    ));
    $wp_customize->add_setting('fashion_blogs_twitter_icon',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('fashion_blogs_twitter_icon',array(
        'label' => esc_html__('Add Twitter Icon','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_twitter_icon',
        'type'  => 'text',
        'default' => 'fab fa-twitter',
        'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fab fa-twitter','fashion-blogs')
    ));

    $wp_customize->add_setting('fashion_blogs_twitter_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('fashion_blogs_twitter_url',array(
        'label' => esc_html__('Twitter Link','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_twitter_url',
        'type'  => 'url'
    ));
    $wp_customize->add_setting('fashion_blogs_intagram_icon',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('fashion_blogs_intagram_icon',array(
        'label' => esc_html__('Add Intagram Icon','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_intagram_icon',
        'type'  => 'text',
        'default' => 'fab fa-instagram',
        'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fab fa-instagram','fashion-blogs')
    ));

    $wp_customize->add_setting('fashion_blogs_intagram_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('fashion_blogs_intagram_url',array(
        'label' => esc_html__('Intagram Link','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_intagram_url',
        'type'  => 'url'
    ));
     $wp_customize->add_setting('fashion_blogs_linkedin_icon',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('fashion_blogs_linkedin_icon',array(
        'label' => esc_html__('Add Linkedin Icon','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_linkedin_icon',
        'type'  => 'text',
        'default' => 'fab fa-linkedin-in',
        'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fab fa-linkedin-in','fashion-blogs')
    ));

    $wp_customize->add_setting('fashion_blogs_linkedin_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('fashion_blogs_linkedin_url',array(
        'label' => esc_html__('Linkedin Link','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_linkedin_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('fashion_blogs_pintrest_icon',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('fashion_blogs_pintrest_icon',array(
        'label' => esc_html__('Add Pinterest Icon','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_pintrest_icon',
        'type'  => 'text',
        'default' => 'fab fa-pinterest-p',
        'description' =>  __('Select font awesome icons <a target="_blank" href="https://fontawesome.com/v5/search?m=free">Click Here</a> for select icon. for eg:-fab fa-pinterest-p','fashion-blogs')
    ));

    $wp_customize->add_setting('fashion_blogs_pintrest_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('fashion_blogs_pintrest_url',array(
        'label' => esc_html__('Pinterest Link','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_pintrest_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('fashion_blogs_subscribe_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('fashion_blogs_subscribe_text',array(
        'label' => esc_html__('Subscribe Text','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_subscribe_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('fashion_blogs_subscribe_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('fashion_blogs_subscribe_url',array(
        'label' => esc_html__('Subscribe URL','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_subscribe_url',
        'type'  => 'url'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_header_setting', array(
        'sanitize_callback' => 'Fashion_Blogs_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Fashion_Blogs_Customize_Pro_Version ( $wp_customize,'pro_version_header_setting', array(
        'section'     => 'fashion_blogs_top_header',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'fashion-blogs' ),
        'description' => esc_url( FASHION_BLOGS_URL ),
        'priority'    => 100
    )));

    //Slider
    $wp_customize->add_section('fashion_blogs_top_slider',array(
        'title' => esc_html__('Slider Option','fashion-blogs')
    ));

    $wp_customize->add_setting('fashion_blogs_slide_setting', array(
        'default' => 0,
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'fashion_blogs_slide_setting',array(
        'label'          => __( 'Enable Disable Slider', 'fashion-blogs' ),
        'section'        => 'fashion_blogs_top_slider',
        'settings'       => 'fashion_blogs_slide_setting',
        'type'           => 'checkbox',
    )));

    for ( $fashion_blog_count = 1; $fashion_blog_count <= 3; $fashion_blog_count++ ) {
        $wp_customize->add_setting( 'fashion_blogs_top_slider_page' . $fashion_blog_count, array(
            'default'           => '',
            'sanitize_callback' => 'fashion_blogs_sanitize_dropdown_pages'
        ) );
        $wp_customize->add_control( 'fashion_blogs_top_slider_page' . $fashion_blog_count, array(
            'label'    => __( 'Select Slide Page', 'fashion-blogs' ),
            'section'  => 'fashion_blogs_top_slider',
            'type'     => 'dropdown-pages'
        ) );
    }

    //Slider Image Opacity
    $wp_customize->add_setting('fashion_blogs_slider_opacity_color',array(
      'default' => '',
      'sanitize_callback' => 'fashion_blogs_sanitize_choices'
    ));

    $wp_customize->add_control( 'fashion_blogs_slider_opacity_color', array(
    'label'       => esc_html__( 'Slider Image Opacity','fashion-blogs' ),
    'section'     => 'fashion_blogs_top_slider',
    'type'        => 'select',
    'choices' => array(
      '0' =>  esc_attr('0','fashion-blogs'),
      '0.1' =>  esc_attr('0.1','fashion-blogs'),
      '0.2' =>  esc_attr('0.2','fashion-blogs'),
      '0.3' =>  esc_attr('0.3','fashion-blogs'),
      '0.4' =>  esc_attr('0.4','fashion-blogs'),
      '0.5' =>  esc_attr('0.5','fashion-blogs'),
      '0.6' =>  esc_attr('0.6','fashion-blogs'),
      '0.7' =>  esc_attr('0.7','fashion-blogs'),
      '0.8' =>  esc_attr('0.8','fashion-blogs'),
      '0.9' =>  esc_attr('0.9','fashion-blogs')
    ),
    ));

    //Slider height
    $wp_customize->add_setting('fashion_blogs_slider_img_height',array(
        'default'=> '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('fashion_blogs_slider_img_height',array(
        'label' => __('Slider Height','fashion-blogs'),
        'description'   => __('Add the slider height in px(eg. 500px).','fashion-blogs'),
        'input_attrs' => array(
            'placeholder' => __( '500px', 'fashion-blogs' ),
        ),
        'section'=> 'fashion_blogs_top_slider',
        'type'=> 'text'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_slider_setting', array(
        'sanitize_callback' => 'Fashion_Blogs_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Fashion_Blogs_Customize_Pro_Version ( $wp_customize,'pro_version_slider_setting', array(
        'section'     => 'fashion_blogs_top_slider',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'fashion-blogs' ),
        'description' => esc_url( FASHION_BLOGS_URL ),
        'priority'    => 100
    )));

    // Latest Post Section
    $wp_customize->add_section('fashion_blogs_latest_post',array(
        'title' => esc_html__('Latest Post Section','fashion-blogs')
    ));

    $wp_customize->add_setting('fashion_blogs_latest_post_setting', array(
        'default' => 0,
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'fashion_blogs_latest_post_setting',array(
        'label'          => __( 'Enable Disable Latest Post', 'fashion-blogs' ),
        'section'        => 'fashion_blogs_latest_post',
        'settings'       => 'fashion_blogs_latest_post_setting',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('fashion_blogs_latest_post_title',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('fashion_blogs_latest_post_title',array(
        'label' => esc_html__('Section Title','fashion-blogs'),
        'section' => 'fashion_blogs_latest_post',
        'setting' => 'fashion_blogs_latest_post_title',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('fashion_blogs_latest_post_loop',array(
        'default'   => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('fashion_blogs_latest_post_loop',array(
        'label' => esc_html__('No of latest post','fashion-blogs'),
        'section'   => 'fashion_blogs_latest_post',
        'type'      => 'number',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 0,
            'max'              => 12,
        ),
    ));

    $latest_post_loop = get_theme_mod('fashion_blogs_latest_post_loop');

    $fashion_blog_args = array('numberposts' => -1);
    $post_list = get_posts($fashion_blog_args);
    $i = 1;
    $pst_sls[]= __('Select','fashion-blogs');
    foreach ($post_list as $key => $p_post) {
        $pst_sls[$p_post->ID]=$p_post->post_title;
    }
    for ( $i = 1; $i <= $latest_post_loop; $i++ ) {
        $wp_customize->add_setting('fashion_blogs_other_latest_post_section'.$i,array(
            'sanitize_callback' => 'fashion_blogs_sanitize_choices',
        ));
        $wp_customize->add_control('fashion_blogs_other_latest_post_section'.$i,array(
            'type'    => 'select',
            'choices' => $pst_sls,
            'label' => __('Select Post','fashion-blogs'),
            'section' => 'fashion_blogs_latest_post',
        ));
    }
    wp_reset_postdata();

     // Pro Version
    $wp_customize->add_setting( 'pro_version_latest_post_setting', array(
        'sanitize_callback' => 'Fashion_Blogs_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Fashion_Blogs_Customize_Pro_Version ( $wp_customize,'pro_version_latest_post_setting', array(
        'section'     => 'fashion_blogs_latest_post',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'fashion-blogs' ),
        'description' => esc_url( FASHION_BLOGS_URL ),
        'priority'    => 100
    )));

    // Footer
    $wp_customize->add_section('fashion_blogs_site_footer_section', array(
        'title' => esc_html__('Footer', 'fashion-blogs'),
    ));

    $wp_customize->add_setting('fashion_blogs_footer_bg_image',array(
        'default'   => '',
        'sanitize_callback' => 'esc_url_raw',
    ));
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'fashion_blogs_footer_bg_image',array(
        'label' => __('Footer Background Image','fashion-blogs'),
        'section' => 'fashion_blogs_site_footer_section',
        'priority' => 1,
    )));

    $wp_customize->add_setting('fashion_blogs_footer_text_setting', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control('fashion_blogs_footer_text_setting', array(
        'label' => __('Replace the footer text', 'fashion-blogs'),
        'section' => 'fashion_blogs_site_footer_section',
        'priority' => 1,
        'type' => 'text',
    ));

    $wp_customize->add_setting('fashion_blogs_show_hide_copyright',array(
        'default' => true,
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control('fashion_blogs_show_hide_copyright',array(
        'type' => 'checkbox',
        'label' => __('Show / Hide Copyright','fashion-blogs'),
        'section' => 'fashion_blogs_site_footer_section',
    ));

    $wp_customize->add_setting('fashion_blogs_copyright_background_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'fashion_blogs_copyright_background_color', array(
        'label'    => __('Copyright Background Color', 'fashion-blogs'),
        'section'  => 'fashion_blogs_site_footer_section',
    )));

     // Pro Version
    $wp_customize->add_setting( 'pro_version_footer_setting', array(
        'sanitize_callback' => 'Fashion_Blogs_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Fashion_Blogs_Customize_Pro_Version ( $wp_customize,'pro_version_footer_setting', array(
        'section'     => 'fashion_blogs_site_footer_section',
        'type'        => 'pro_options',
        'label'       => esc_html__( 'Customizer Options', 'fashion-blogs' ),
        'description' => esc_url( FASHION_BLOGS_URL ),
        'priority'    => 100
    )));

    // Post Settings
     $wp_customize->add_section('fashion_blogs_post_settings',array(
        'title' => esc_html__('Post Settings','fashion-blogs'),
        'priority'   =>40,
    ));

    $wp_customize->add_setting('fashion_blogs_post_page_title',array(
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('fashion_blogs_post_page_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Title', 'fashion-blogs'),
        'section'     => 'fashion_blogs_post_settings',
        'description' => esc_html__('Check this box to enable title on post page.', 'fashion-blogs'),
    ));

    $wp_customize->add_setting('fashion_blogs_post_page_meta',array(
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('fashion_blogs_post_page_meta',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Meta', 'fashion-blogs'),
        'section'     => 'fashion_blogs_post_settings',
        'description' => esc_html__('Check this box to enable meta on post page.', 'fashion-blogs'),
    ));

    $wp_customize->add_setting('fashion_blogs_post_page_thumb',array(
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('fashion_blogs_post_page_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Thumbnail', 'fashion-blogs'),
        'section'     => 'fashion_blogs_post_settings',
        'description' => esc_html__('Check this box to enable thumbnail on post page.', 'fashion-blogs'),
    ));

    $wp_customize->add_setting('fashion_blogs_post_page_btn',array(
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('fashion_blogs_post_page_btn',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Button', 'fashion-blogs'),
        'section'     => 'fashion_blogs_post_settings',
        'description' => esc_html__('Check this box to enable button on post page.', 'fashion-blogs'),
    ));

    $wp_customize->add_setting('fashion_blogs_single_post_thumb',array(
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('fashion_blogs_single_post_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Thumbnail', 'fashion-blogs'),
        'section'     => 'fashion_blogs_post_settings',
        'description' => esc_html__('Check this box to enable post thumbnail on single post.', 'fashion-blogs'),
    ));

    $wp_customize->add_setting('fashion_blogs_single_post_meta',array(
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('fashion_blogs_single_post_meta',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Meta', 'fashion-blogs'),
        'section'     => 'fashion_blogs_post_settings',
        'description' => esc_html__('Check this box to enable single post meta such as post date, author, category, comment etc.', 'fashion-blogs'),
    ));

    $wp_customize->add_setting('fashion_blogs_single_post_title',array(
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('fashion_blogs_single_post_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Title', 'fashion-blogs'),
        'section'     => 'fashion_blogs_post_settings',
        'description' => esc_html__('Check this box to enable title on single post.', 'fashion-blogs'),
    ));

    $wp_customize->add_setting('fashion_blogs_single_post_comment_title',array(
        'default'=> 'Leave a Reply',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_setting('fashion_blogs_single_post_navigation_show_hide',array(
        'default' => true,
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control('fashion_blogs_single_post_navigation_show_hide',array(
        'type' => 'checkbox',
        'label' => __('Show / Hide Post Navigation','fashion-blogs'),
        'section' => 'fashion_blogs_post_settings',
    ));

    $wp_customize->add_control('fashion_blogs_single_post_comment_title',array(
        'label' => __('Add Comment Title','fashion-blogs'),
        'input_attrs' => array(
        'placeholder' => __( 'Leave a Reply', 'fashion-blogs' ),
        ),
        'section'=> 'fashion_blogs_post_settings',
        'type'=> 'text'
    ));

    $wp_customize->add_setting('fashion_blogs_single_post_comment_btn_text',array(
        'default'=> 'Post Comment',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('fashion_blogs_single_post_comment_btn_text',array(
        'label' => __('Add Comment Button Text','fashion-blogs'),
        'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'fashion-blogs' ),
        ),
        'section'=> 'fashion_blogs_post_settings',
        'type'=> 'text'
    ));

    // Page Settings
    $wp_customize->add_section('fashion_blogs_page_settings',array(
        'title' => esc_html__('Page Settings','fashion-blogs'),
        'priority'   =>50,
    ));

    $wp_customize->add_setting('fashion_blogs_single_page_title',array(
            'sanitize_callback' => 'fashion_blogs_sanitize_checkbox',
            'default'           => 1,
    ));
    $wp_customize->add_control('fashion_blogs_single_page_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Page Title', 'fashion-blogs'),
        'section'     => 'fashion_blogs_page_settings',
        'description' => esc_html__('Check this box to enable title on single page.', 'fashion-blogs'),
    ));

    $wp_customize->add_setting('fashion_blogs_single_page_thumb',array(
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('fashion_blogs_single_page_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Page Thumbnail', 'fashion-blogs'),
        'section'     => 'fashion_blogs_page_settings',
        'description' => esc_html__('Check this box to enable page thumbnail on single page.', 'fashion-blogs'),
    ));
}
add_action('customize_register', 'fashion_blogs_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function fashion_blogs_customize_partial_blogname(){
    bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function fashion_blogs_customize_partial_blogdescription(){
    bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function fashion_blogs_customize_preview_js(){
    wp_enqueue_script('fashion-blogs-customizer', esc_url(get_template_directory_uri()) . '/assets/js/customizer.js', array('customize-preview'), '20151215', true);
}
add_action('customize_preview_init', 'fashion_blogs_customize_preview_js');

/*
** Load dynamic logic for the customizer controls area.
*/
function fashion_blogs_panels_js() {
    wp_enqueue_style( 'fashion-blogs-customizer-layout-css', get_theme_file_uri( '/assets/css/customizer-layout.css' ) );
    wp_enqueue_script( 'fashion-blogs-customize-layout', get_theme_file_uri( '/assets/js/customize-layout.js' ), array(), '1.2', true );
}
add_action( 'customize_controls_enqueue_scripts', 'fashion_blogs_panels_js' );
